Stan Math Library: stan/math/prim/mat/err/check_range.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
check_range.hpp File Reference
`#include <stan/math/prim/scal/err/out_of_range.hpp>`
`#include <stan/math/prim/mat/meta/index_type.hpp>`
`#include <stan/math/prim/scal/meta/error_index.hpp>`
`#include <sstream>`
`#include <string>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
bool | stan::math::check_range (const char *function, const char *name, const int max, const int index, const int nested_level, const char *error_msg)
| Return `true` if specified index is within range. More...
bool | stan::math::check_range (const char *function, const char *name, const int max, const int index, const char *error_msg)
| Return `true` if specified index is within range. More...
bool | stan::math::check_range (const char *function, const char *name, const int max, const int index)
| Return `true` if specified index is within range. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.